==> kubernetes-model-1.0.62-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerImageBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class ContainerImageBuilder extends ContainerImageFluentImpl<ContainerImageBuilder> implements VisitableBuilder<ContainerImage,ContainerImageBuilder>{

    ContainerImageFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerImageBuilder(){
            this(true);
    }
    public ContainerImageBuilder(Boolean validationEnabled){
            this(new ContainerImage(), validationEnabled);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerImage(), validationEnabled);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent,ContainerImage instance){
            this(fluent, instance, true);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent,ContainerImage instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withNames(instance.getNames()); 
            fluent.withSizeBytes(instance.getSizeBytes()); 
            this.validationEnabled = validationEnabled; 
    }
    public ContainerImageBuilder(ContainerImage instance){
            this(instance,true);
    }
    public ContainerImageBuilder(ContainerImage instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withNames(instance.getNames()); 
            this.withSizeBytes(instance.getSizeBytes()); 
            this.validationEnabled = validationEnabled; 
    }

    public ContainerImage build(){
            ContainerImage buildable = new ContainerImage(fluent.getNames(),fluent.getSizeBytes());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerImageBuilder that = (ContainerImageBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerImageBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ContainerImageBuilder extends ContainerImageFluentImpl<ContainerImageBuilder> implements VisitableBuilder<ContainerImage,ContainerImageBuilder>{

    ContainerImageFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerImageBuilder(){
            this(true);
    }
    public ContainerImageBuilder(Boolean validationEnabled){
            this(new ContainerImage(), validationEnabled);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerImage(), validationEnabled);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent,ContainerImage instance){
            this(fluent, instance, true);
    }
    public ContainerImageBuilder(ContainerImageFluent<?> fluent,ContainerImage instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withNames(instance.getNames()); 
            fluent.withSizeBytes(instance.getSizeBytes()); 
            this.validationEnabled = validationEnabled; 
    }
    public ContainerImageBuilder(ContainerImage instance){
            this(instance,true);
    }
    public ContainerImageBuilder(ContainerImage instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withNames(instance.getNames()); 
            this.withSizeBytes(instance.getSizeBytes()); 
            this.validationEnabled = validationEnabled; 
    }

    public ContainerImage build(){
            ContainerImage buildable = new ContainerImage(fluent.getNames(),fluent.getSizeBytes());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerImageBuilder that = (ContainerImageBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
